@@ -21,8 +21,13 @@ class TabFit(QtWidgets.QWidget):
         # Exact spherical model is only available in developer mode
         self.settings = QtCore.QSettings()
         self.settings.setIniCodec("utf-8")
-        if not bool(int(self.settings.value("advanced/developer mode", "0"))):
+        dev_mode = bool(int(
+            self.settings.value("advanced/developer mode", "0")))
+        exp_mode = bool(int(
+            self.settings.value("advanced/expert mode", "0")))
+        if not dev_mode:
             models_av.remove("sneddon_spher")
+        if not (dev_mode or exp_mode):
             self.widget_method.hide()
         models_av.sort(key=lambda x: nmodel.models_available[x].model_name)
         for ii, key in enumerate(models_av):
@@ -44,6 +49,10 @@ class TabFit(QtWidgets.QWidget):
         # i.e. `self.cb_delta_select.currentIndex == 1`)
         self.cb_right_individ.setVisible(False)
 
+        # Show axes selection only in developer mode
+        for wid in [self.label_axes, self.widget_axes]:
+            wid.setVisible(dev_mode)
+
         # signals
         self.cb_segment.currentIndexChanged.connect(self.on_params_init)
         self.cb_xaxis.currentIndexChanged.connect(self.on_params_init)
@@ -56,6 +65,7 @@ class TabFit(QtWidgets.QWidget):
         self.sp_weight_cp_um.valueChanged.connect(self.on_update_weights)
         self.sp_weight_cp_perc.valueChanged.connect(self.on_update_weights)
         self.toolButton_method_apply.clicked.connect(self.on_params_init)
+        self.sp_gcfk.valueChanged.connect(self.on_params_init)
 
     @property
     def current_curve(self):
@@ -90,24 +100,25 @@ class TabFit(QtWidgets.QWidget):
             for ak in self.fit_model.parameter_anc_keys:
                 if ak not in anc_used:
                     continue
-                # Get the human readable name of the parameter
+                # Get the human-readable name of the parameter
                 hrname = self.fit_model.get_parm_name(ak)
                 # Determine unit scale, e.g. 1e6 [sic] for µm
                 si_unit = self.fit_model.get_parm_unit(ak)
                 # Determine unit scale, e.g. 1e6 [sic] for µm
                 scale = units.hrscale(hrname, si_unit=si_unit)
                 label = units.hrscname(hrname, si_unit=si_unit)
+                value_text = "{:.5g}".format(anc[ak] * scale)
                 atab.verticalHeaderItem(row).setText(label)
                 if rows_changed:
                     atab.item(row, 0).setCheckState(QtCore.Qt.Checked)
-                atab.item(row, 1).setText("{:.5g}".format(anc[ak] * scale))
+                atab.item(row, 1).setText(value_text)
                 # updates initial parameters if "use" is checked
                 if atab.item(row, 0).checkState() == QtCore.Qt.Checked:
                     # update initial parameters
-                    idx = self.fit_model.parameter_keys.index(ak)
-                    text = atab.item(row, 1).text()
-                    if text != "nan":
-                        itab.item(idx, 1).setText(text)
+                    for rr in range(itab.rowCount()):
+                        if itab.verticalHeaderItem(rr).text() == label:
+                            if value_text != "nan":
+                                itab.item(rr, 1).setText(value_text)
                 row += 1
             atab.blockSignals(False)
         else:
@@ -130,7 +141,7 @@ class TabFit(QtWidgets.QWidget):
         Returns
         -------
         rows_changed: bool
-            Whether or not the number of rows changed
+            Whether the number of rows changed
         """
         rows_changed = (table.rowCount() - rows) != 0
         table.setRowCount(rows)
@@ -170,6 +181,8 @@ class TabFit(QtWidgets.QWidget):
         """
         dev_mode = bool(int(
             self.settings.value("advanced/developer mode", "0")))
+        exp_mode = bool(int(
+            self.settings.value("advanced/expert mode", "0")))
         # segment
         segment = self.cb_segment.currentText().lower()
         # x axis
@@ -178,6 +191,8 @@ class TabFit(QtWidgets.QWidget):
         y_axis = self.cb_yaxis.currentText()
         # Get model key from dropdown list
         model_key = self.fit_model.model_key
+        # Geometric factor
+        gcf_k = self.sp_gcfk.value()
         # Determine range type
         if self.cb_range_type.currentText() == "absolute":
             range_type = "absolute"
@@ -208,8 +223,8 @@ class TabFit(QtWidgets.QWidget):
         params = self.fit_parameters()
         # fit method (if in developer mode)
         kwargs = {}
-        if dev_mode:
-            # We are in developer mode.
+        if dev_mode or exp_mode:
+            # We are in developer or expert mode.
             # Populate the user-defined keyword arguments. Note that
             # these are not passed as "options", but directly to the
             # minimizer method.
@@ -233,6 +248,7 @@ class TabFit(QtWidgets.QWidget):
                         segment=segment,
                         optimal_fit_edelta=optimal_fit_edelta,
                         optimal_fit_num_samples=optimal_fit_num_samples,
+                        gcf_k=gcf_k,
                         **kwargs
                         )
         ftab = self.table_parameters_fitted
@@ -277,7 +293,7 @@ class TabFit(QtWidgets.QWidget):
                     ftab.item(ii, 0).setText("nan")
 
     def fit_parameters(self):
-        """Returns parameters currently set in the GUI
+        """Return initial fit parameters currently set in the GUI
 
         The parameter data is read out from
         `self.table_parameters_initial`. If the model that was
@@ -502,31 +518,27 @@ class TabFit(QtWidgets.QWidget):
         radio button.
         """
         # First get the tip radius
-        params = self.fit_model.get_parameter_defaults()
-        itab = self.table_parameters_initial
-        for ii, key in enumerate(list(params.keys())):
-            if key == "R":
-                radius = float(itab.item(ii, 1).text())
-                # Make sure the "% tip radius" radio button is enabled,
-                # because it could have been disabled for a fit model that
-                # does not contain the parameter "R".
-                self.rd_weigt_perc.setEnabled(True)
-                # Did the user select "% tip radius"?
-                percent = self.rd_weigt_perc.isChecked()
-
-                if percent:
-                    # set um value
-                    perc = self.sp_weight_cp_perc.value()
-                    self.sp_weight_cp_um.blockSignals(True)
-                    self.sp_weight_cp_um.setValue(radius * perc / 100)
-                    self.sp_weight_cp_um.blockSignals(False)
-                else:
-                    # set percent value
-                    val = self.sp_weight_cp_um.value()
-                    self.sp_weight_cp_perc.blockSignals(True)
-                    self.sp_weight_cp_perc.setValue(val / radius * 100)
-                    self.sp_weight_cp_perc.blockSignals(False)
-                break
+        params = self.fit_parameters()
+        if "R" in params:
+            radius = params["R"].value * units.hrscale("tip radius")
+            # Make sure the "% tip radius" radio button is enabled,
+            # because it could have been disabled for a fit model that
+            # does not contain the parameter "R".
+            self.rd_weigt_perc.setEnabled(True)
+            # Did the user select "% tip radius"?
+            percent = self.rd_weigt_perc.isChecked()
+            if percent:
+                # set um value
+                perc = self.sp_weight_cp_perc.value()
+                self.sp_weight_cp_um.blockSignals(True)
+                self.sp_weight_cp_um.setValue(radius * perc / 100)
+                self.sp_weight_cp_um.blockSignals(False)
+            else:
+                # set percent value
+                val = self.sp_weight_cp_um.value()
+                self.sp_weight_cp_perc.blockSignals(True)
+                self.sp_weight_cp_perc.setValue(val / radius * 100)
+                self.sp_weight_cp_perc.blockSignals(False)
         else:
             # The key "R" could not be found. This means we
             # have a model that does not allow to compute the
